@@ -4,9 +4,10 @@
 
 from models import Setup
 from django.contrib import admin
-# from forms import SetupForm
+from forms import SetupForm
 from django.utils.translation import ugettext_lazy as _
 
+
 class SetupAdmin(admin.ModelAdmin):
     list_display = ('slug', 'active')
 
@@ -20,6 +21,5 @@ class SetupAdmin(admin.ModelAdmin):
             }),
             )
 
-    # TODO - djangos passwod input loose displayed string
-    # form = SetupForm
+    form = SetupForm
 admin.site.register(Setup, SetupAdmin)
