@@ -3,11 +3,10 @@
 # This Python file uses the following encoding: utf-8
 
 from django.forms import ModelForm, PasswordInput
-from models import Setup
+
 
 class SetupForm(ModelForm):
     class Meta:
-        model = Setup
         widgets = {
-            'mail_host_pass': PasswordInput(),
+            'mail_host_pass': PasswordInput(render_value=True),
         }
